# Tools `tl`

Analysis tools for clustering seqlets and pattern discovery.

```{eval-rst}
.. module:: tfmindi.tl
.. currentmodule:: tfmindi

.. autosummary::
    :toctree: ../generated

    tl.cluster_seqlets
    tl.create_patterns
    tl.run_topic_modeling
    tl.evaluate_topic_models

```
